@@ -66,6 +66,18 @@ g_tls_connection_openssl_finalize (GObject *object)
   G_OBJECT_CLASS (g_tls_connection_openssl_parent_class)->finalize (object);
 }
 
+static GTlsSafeRenegotiationStatus
+g_tls_connection_openssl_handshake_thread_safe_renegotiation_status (GTlsConnectionBase *tls)
+{
+  GTlsConnectionOpenssl *openssl = G_TLS_CONNECTION_OPENSSL (tls);
+  SSL *ssl;
+
+  ssl = g_tls_connection_openssl_get_ssl (openssl);
+
+  return SSL_get_secure_renegotiation_support (ssl) ? G_TLS_SAFE_RENEGOTIATION_SUPPORTED_BY_PEER
+                                                    : G_TLS_SAFE_RENEGOTIATION_UNSUPPORTED;
+}
+
 static GTlsConnectionBaseStatus
 end_openssl_io (GTlsConnectionOpenssl  *openssl,
                 GIOCondition            direction,
@@ -135,8 +147,8 @@ end_openssl_io (GTlsConnectionOpenssl  *openssl,
           reason == SSL_R_UNKNOWN_PROTOCOL)
         {
           g_clear_error (&my_error);
-          g_set_error_literal (error, G_TLS_ERROR, G_TLS_ERROR_NOT_TLS,
-                               _("Peer failed to perform TLS handshake"));
+          g_set_error (error, G_TLS_ERROR, G_TLS_ERROR_NOT_TLS,
+                       _("Peer failed to perform TLS handshake: %s"), ERR_reason_error_string (err));
           return G_TLS_CONNECTION_BASE_ERROR;
         }
     }
@@ -189,7 +201,7 @@ end_openssl_io (GTlsConnectionOpenssl  *openssl,
       return G_TLS_CONNECTION_BASE_ERROR;
     }
 
-  if (my_error != NULL)
+  if (my_error)
     g_propagate_error (error, my_error);
   else
     /* FIXME: this is just for debug */
@@ -213,10 +225,10 @@ end_openssl_io (GTlsConnectionOpenssl  *openssl,
   } while (status == G_TLS_CONNECTION_BASE_TRY_AGAIN);
 
 static GTlsConnectionBaseStatus
-g_tls_connection_openssl_request_rehandshake (GTlsConnectionBase  *tls,
-                                              gint64               timeout,
-                                              GCancellable        *cancellable,
-                                              GError             **error)
+g_tls_connection_openssl_handshake_thread_request_rehandshake (GTlsConnectionBase  *tls,
+                                                               gint64               timeout,
+                                                               GCancellable        *cancellable,
+                                                               GError             **error)
 {
   GTlsConnectionOpenssl *openssl;
   GTlsConnectionBaseStatus status;
@@ -270,11 +282,11 @@ g_tls_connection_openssl_retrieve_peer_certificate (GTlsConnectionBase *tls)
   ssl = g_tls_connection_openssl_get_ssl (G_TLS_CONNECTION_OPENSSL (tls));
 
   peer = SSL_get_peer_certificate (ssl);
-  if (peer == NULL)
+  if (!peer)
     return NULL;
 
   certs = SSL_get_peer_cert_chain (ssl);
-  if (certs == NULL)
+  if (!certs)
     {
       X509_free (peer);
       return NULL;
@@ -420,8 +432,7 @@ g_tls_connection_openssl_read (GTlsConnectionBase    *tls,
       g_tls_bio_wait_available (priv->bio, G_IO_IN, cancellable);
     }
 
-  if (ret >= 0)
-    *nread = ret;
+  *nread = MAX (ret, 0);
   return status;
 }
 
@@ -465,8 +476,7 @@ g_tls_connection_openssl_write (GTlsConnectionBase    *tls,
       g_tls_bio_wait_available (priv->bio, G_IO_OUT, cancellable);
     }
 
-  if (ret >= 0)
-    *nwrote = ret;
+  *nwrote = MAX (ret, 0);
   return status;
 }
 
@@ -505,16 +515,17 @@ g_tls_connection_openssl_class_init (GTlsConnectionOpensslClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GTlsConnectionBaseClass *base_class = G_TLS_CONNECTION_BASE_CLASS (klass);
 
-  object_class->finalize                 = g_tls_connection_openssl_finalize;
+  object_class->finalize                                 = g_tls_connection_openssl_finalize;
 
-  base_class->request_rehandshake        = g_tls_connection_openssl_request_rehandshake;
-  base_class->handshake_thread_handshake = g_tls_connection_openssl_handshake_thread_handshake;
-  base_class->retrieve_peer_certificate  = g_tls_connection_openssl_retrieve_peer_certificate;
-  base_class->push_io                    = g_tls_connection_openssl_push_io;
-  base_class->pop_io                     = g_tls_connection_openssl_pop_io;
-  base_class->read_fn                    = g_tls_connection_openssl_read;
-  base_class->write_fn                   = g_tls_connection_openssl_write;
-  base_class->close_fn                   = g_tls_connection_openssl_close;
+  base_class->handshake_thread_safe_renegotiation_status = g_tls_connection_openssl_handshake_thread_safe_renegotiation_status;
+  base_class->handshake_thread_request_rehandshake       = g_tls_connection_openssl_handshake_thread_request_rehandshake;
+  base_class->handshake_thread_handshake                 = g_tls_connection_openssl_handshake_thread_handshake;
+  base_class->retrieve_peer_certificate                  = g_tls_connection_openssl_retrieve_peer_certificate;
+  base_class->push_io                                    = g_tls_connection_openssl_push_io;
+  base_class->pop_io                                     = g_tls_connection_openssl_pop_io;
+  base_class->read_fn                                    = g_tls_connection_openssl_read;
+  base_class->write_fn                                   = g_tls_connection_openssl_write;
+  base_class->close_fn                                   = g_tls_connection_openssl_close;
 }
 
 static int data_index = -1;
@@ -533,12 +544,12 @@ g_tls_connection_openssl_initable_init (GInitable     *initable,
   g_object_get (tls,
                 "base-io-stream", &base_io_stream,
                 NULL);
-  g_return_val_if_fail (base_io_stream != NULL, FALSE);
+  g_return_val_if_fail (base_io_stream, FALSE);
 
   priv = g_tls_connection_openssl_get_instance_private (openssl);
 
   ssl = g_tls_connection_openssl_get_ssl (openssl);
-  g_assert (ssl != NULL);
+  g_assert (ssl);
 
   if (data_index == -1) {
       data_index = SSL_get_ex_new_index (0, (void *)"gtlsconnection", NULL, NULL, NULL);
@@ -579,7 +590,7 @@ g_tls_connection_openssl_get_ssl (GTlsConnectionOpenssl *openssl)
 GTlsConnectionOpenssl *
 g_tls_connection_openssl_get_connection_from_ssl (SSL *ssl)
 {
-  g_return_val_if_fail (ssl != NULL, NULL);
+  g_return_val_if_fail (ssl, NULL);
 
   return SSL_get_ex_data (ssl, data_index);
 }
